#
# spec file for package python-argcomplete
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2013 Darin Perusich.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{!?license: %global license %doc}
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-argcomplete
Version:        1.9.2
Release:        lp152.3.21
Summary:        Bash tab completion for argparse
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://github.com/kislyuk/argcomplete
Source:         https://files.pythonhosted.org/packages/source/a/argcomplete/argcomplete-%{version}.tar.gz
Patch0:         skip_tcsh_tests.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
# SECTION tests
BuildRequires:  %{python_module coverage}
BuildRequires:  %{python_module flake8}
BuildRequires:  %{python_module pexpect}
BuildRequires:  %{python_module wheel}
# END SECTIONS tests
Requires:       python-wheel
BuildArch:      noarch
%python_subpackages

%description
Argcomplete provides easy, extensible command line tab completion of
arguments for your Python script.

It makes two assumptions:

* You're using bash as your shell
* You're using argparse to manage your command line arguments/options

Argcomplete is particularly useful if your program has lots of options
or subparsers, and if your program can dynamically suggest completions
for your argument/option values (for example, if the user is browsing
resources over the network).

%prep
%setup -q -n argcomplete-%{version}
%patch0 -p1

%build
%python_build

%install
%python_install
rm -rf %{buildroot}%{python_sitelib}/test
rm %{buildroot}%{_bindir}/activate-global-python-argcomplete
%python_clone %{buildroot}%{_bindir}/python-argcomplete-check-easy-install-script
%python_clone %{buildroot}%{_bindir}/register-python-argcomplete
install -DTm644 %{buildroot}%{python_sitelib}/argcomplete/bash_completion.d/python-argcomplete.sh %{buildroot}%{_sysconfdir}/bash_completion.d/python-argcomplete.sh
%python_clone %{buildroot}%{_sysconfdir}/bash_completion.d/python-argcomplete.sh
# tcsh support is broken
rm %{buildroot}%{_bindir}/python-argcomplete-tcsh

%check
export LANG=en_US.UTF-8
%python_exec setup.py test

%files %{python_files}
%defattr(-,root,root)
%doc README.rst
%license LICENSE.rst
%{python_sitelib}/argcomplete-%{version}-py%{python_version}.egg-info
%{python_sitelib}/argcomplete
%python3_only %{_bindir}/python-argcomplete-check-easy-install-script
%python3_only %{_bindir}/register-python-argcomplete
%python3_only %{_sysconfdir}/bash_completion.d/python-argcomplete.sh
%{_bindir}/python-argcomplete-check-easy-install-script-%{python_version}
%{_bindir}/register-python-argcomplete-%{python_version}
%{_sysconfdir}/bash_completion.d/python-argcomplete.sh-%{python_version}

%changelog
* Fri Sep 15 2017 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.9.2
- Update patch to skip broken tcsh tests
  + skip_tcsh_tests.patch
- Fix issues with singlespec auto-conversion
  + Install %%{python_sitelib}/bash_completion.d/python-argcomplete.sh
    into %%{_sysconfdir}/bash_completion.d/
  + Use %%python_clone to create both Python 2 and Python 3 versions
    of all scripts below /usr/bin and /etc/bash_completion.d
    with the %%{python_version} suffix; also install the Python 3
    versions without the suffix
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Thu Jul 20 2017 sebix+novell.com@sebix.at
- update to 1.8.2
- add patch skip_tcsh_tests.patch to skip broken tcsh tests
* Wed Nov  2 2016 achim.herwig@wodca.de
- ported back from python3 package including
  introduced update-alternatives to coexist with corresponding python3 package
* Sat Dec 12 2015 mimi.vx@gmail.com
- update to 1.0.0
  * Don't print args with suppressed help by default; add
  argcomplete.autocomplete(print_suppressed=True) to control this behavior
  * Fix always_complete_options=False support.
  * Correct doc filename in setup.cfg
  * Make context managers exception-safe.
  * Fix issue with non-string choices for arguments.
  * Improve non-ascii argparse argument support on Python 2.7.
* Sun Apr 19 2015 benoit.monin@gmx.fr
- update to 0.8.7:
  * register-python-argcomplete: add option to avoid default
    readline completion. Thanks to @drmalex07 (pull request #99).
- additional changes from 0.8.6:
  * Expand tilde in script name, allowing argcomplete to work
    when invoking scripts from one's home directory. Thanks to
    @VorpalBlade (Issue 104).
- additional changes from 0.8.5:
  * Fix issues related to using argcomplete in a REPL
    environement.
  * New helper method for custom completion display.
  * Expand test suite; formatting cleanup.
- additional changes from 0.8.4:
  * Fix issue related to using argcomplete in a REPL
    environement. Thanks to @wapiflapi (pull request #91).
- additional changes from 0.8.3:
  * Fix multiple issues related to using argcomplete in a REPL
    environement. Thanks to @wapiflapi (pull request #90).
- additional changes from 0.8.2:
  * Don't strip colon prefix in completion results if
    COMP_WORDBREAKS does not contain a colon. Thanks to @berezv
    (pull request #88).
- additional changes from 0.8.1:
  * Use complete --nospace to avoid issues with directory
    completion.
- additional changes from 0.8.0:
  * Refactor main body of code into a class to enable
    subclassing and overriding of functionality (Issue #78).
- additional changes from 0.7.1:
  * New keyword option "argcomplete.autocomplete(validator=...)"
    to supply a custom validator or bypass default validation.
    Thanks to @thijsdezoete (Issue #77).
  * Document debug options.
- additional changes from 0.7.0:
  * New keyword option "argcomplete.autocomplete(exclude=[...])"
    to suppress options (Issue #74).
  * More speedups to code path for global completion hook negative
    result.
- additional changes from 0.6.9:
  * Fix handling of development mode script wrappers. Thanks to
    @jmlopez-rod and @dcosson (Issue #69).
  * Speed up code path for global completion hook negative
    result by loading pkg_resources on demand.
- additional changes from 0.6.8:
  * Begin tracking changes in changelog.
  * Add completion support for PBR installed scripts (PR #71).
  * Detect easy-install shims with shebang lines that contain
    Py instead of py (Issue #69).
* Fri Jan 17 2014 speilicke@suse.com
- Update to version 0.6.7:
  + Upstream provides no changelog
- Don't install testsuite globally
* Mon Nov 18 2013 speilicke@suse.com
- Update to version 0.6.3:
  + No changelog
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Thu May  2 2013 speilicke@suse.com
- Fix SLE builds
- Add LICENSE.rst and README.rst
- Run testsuite
* Mon Apr 29 2013 darin@darins.net
- fixed license, set noarch for build
* Fri Apr 26 2013 darin@darins.net
- add files in _bindir
- add python-distribute
* Fri Apr 26 2013 darin@darins.net
- Initial packaging
